==> nextcloud-app-tasks-0.13.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/nb.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Viktig",
    "Today" : "I dag",
    "Week" : "Uke",
    "All" : "Alle",
    "Current" : "Nåværende",
    "Completed" : "Ferdig",
    "Tasks" : "Oppgaver",
    "The Tasks app for Nextcloud" : "Oppgave-appen for Nextcloud",
    "Add List…" : "Legg til liste...",
    "New List" : "Ny liste",
    "Cancel" : "Avbryt",
    "Save" : "Lagre",
    "The name \"{calendar}\" is already used." : "Navnet \"{calendar}\" er allerede i bruk.",
    "An empty name is not allowed." : "Et tomt navn er ikke tillatt.",
    "Share with users or groups" : "Del med brukere eller grupper",
    "No users or groups" : "Ingen brukere eller grupper",
    "can edit" : "kan redigere",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "Unable to delete the share." : "Kan ikke slette delingen.",
    "Unable to change permissions." : "Kunne ikke endre rettigheter.",
    "Edit" : "Rediger",
    "Copy private link" : "Kopier privat lenke",
    "Copied" : "Kopiert",
    "Can not copy" : "Kan ikke kopiere",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "Unshare" : "Opphev deling",
    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
    "Default list" : "Standardliste",
    "Visibility of Smart Collections" : "Synlighet for smarte samlinger",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Delete all completed tasks." : "Slett alle fullførte oppgaver.",
    "Delete completed tasks." : "Slett fullførte oppgaver.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Slett alle fullførte oppgaver fra kalender \"{calendar}\".",
    "No errors" : "Ingen feil",
    "Open your browser console for more details" : "Åpne din nettlesers konsoll for flere detaljer",
    "Change sort order" : "Endre sorteringsrekkefølge",
    "Relevance" : "Relevans",
    "Start date" : "Startdato",
    "Due date" : "Forfallsdato",
    "Created date" : "Opprettelsesdato",
    "Last modified" : "Sist redigert",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuelt",
    "Task is completed" : "Oppgaven er fullført",
    "Add subtask" : "Legg til underoppgave",
    "Show subtasks" : "Vis underoppgaver",
    "Hide subtasks" : "Skjul underoppgaver",
    "Hide completed subtasks" : "Skjul fullførte underoppgaver",
    "Delete task" : "Slett oppgave",
    "An error occurred, unable to delete the task." : "Det oppstod en feil, kunne ikke slette oppgaven.",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n utført oppgave","%n avsluttede oppgaver"],
    "Tomorrow" : "I morgen",
    "Set start date" : "Sett startdato",
    "Set due date" : "Sett forfallsdato",
    "All day" : "Hele dagen",
    "Add this as a new category" : "Legg til som ny kategori",
    "Task not found!" : "Oppgaven ble ikke funnet!",
    "When shared show full event" : "Vis hele hendelsen når delt",
    "When shared show only busy" : "Vis kun opptatt når delt",
    "When shared hide this event" : "Skjul denne hendelsen når delt",
    "Needs action" : "Krever handling",
    "Canceled" : "Avbrutt",
    "Could not delete the task." : "Kunne ikke slette oppgaven.",
    "An error occurred" : "En feil oppstod"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.14.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/nb.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Viktig",
    "Today" : "I dag",
    "Week" : "Uke",
    "All" : "Alle",
    "Current" : "Nåværende",
    "Completed" : "Ferdig",
    "Tasks" : "Oppgaver",
    "The Tasks app for Nextcloud" : "Oppgave-appen for Nextcloud",
    "Default list" : "Standardliste",
    "Visibility of Smart Collections" : "Synlighet for smarte samlinger",
    "Hidden" : "Skjult",
    "Visible" : "Synlig",
    "Automatic" : "Automatisk",
    "Share with users or groups" : "Del med brukere eller grupper",
    "No users or groups" : "Ingen brukere eller grupper",
    "Unshare with {displayName}" : "Fjern deling med {displayName}",
    "Unable to delete the share." : "Kan ikke slette delingen.",
    "Unable to change permissions." : "Kunne ikke endre rettigheter.",
    "Edit" : "Rediger",
    "Copy private link" : "Kopier privat lenke",
    "Copied" : "Kopiert",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "Unshare" : "Opphev deling",
    "Cancel" : "Avbryt",
    "Save" : "Lagre",
    "Calendar link copied to clipboard." : "Lenke til kalender kopiert til utklippstavle.",
    "Calendar link could not be copied to clipboard." : "Lenke til kalender kunne ikke bli kopiert til utklippstavle.",
    "The name \"{calendar}\" is already used." : "Navnet \"{calendar}\" er allerede i bruk.",
    "An empty name is not allowed." : "Et tomt navn er ikke tillatt.",
    "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
    "Delete all completed tasks." : "Slett alle fullførte oppgaver.",
    "Delete completed tasks." : "Slett fullførte oppgaver.",
    "Deleted all completed tasks from calendar \"{calendar}\"." : "Slett alle fullførte oppgaver fra kalender \"{calendar}\".",
    "No errors" : "Ingen feil",
    "Open your browser console for more details" : "Åpne din nettlesers konsoll for flere detaljer",
    "Load all completed tasks." : "Last alle fullførte oppgaver.",
    "Change sort order" : "Endre sorteringsrekkefølge",
    "Relevance" : "Relevans",
    "Start date" : "Startdato",
    "Due date" : "Forfallsdato",
    "Created date" : "Opprettelsesdato",
    "Last modified" : "Sist redigert",
    "Completed date" : "Fullført dato",
    "Priority" : "Prioritet",
    "Alphabetically" : "Alfabetisk",
    "Manually" : "Manuelt",
    "Task is completed" : "Oppgaven er fullført",
    "{complete} % completed" : "{complete} % utført",
    "Add subtask" : "Legg til underoppgave",
    "Show subtasks" : "Vis underoppgaver",
    "Hide subtasks" : "Skjul underoppgaver",
    "Delete task" : "Slett oppgave",
    "Add a subtask to \"{task}\"…" : "Legg til en underoppgave i \"{task}\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n utført oppgave","%n avsluttede oppgaver"],
    "Tomorrow" : "I morgen",
    "Add List…" : "Legg til liste...",
    "New List" : "Ny liste",
    "All day" : "Hele dagen",
    "Select a status" : "Velg en status",
    "When shared show full event" : "Vis hele hendelsen når delt",
    "When shared show only busy" : "Vis kun opptatt når delt",
    "When shared hide this event" : "Skjul denne hendelsen når delt",
    "Needs action" : "Krever handling",
    "Canceled" : "Avbrutt",
    "Loading task from server." : "Laster oppgaver fra serveren.",
    "Task not found!" : "Oppgaven ble ikke funnet!",
    "Set start date" : "Sett startdato",
    "Set due date" : "Sett forfallsdato",
    "Priority {priority}: low" : "Prioritet {priority}: lav",
    "Priority {priority}: medium" : "Prioritet {priority}: middels",
    "Priority {priority}: high" : "Prioritet {priority}: høy",
    "No priority assigned" : "Ingen tildelt prioritet",
    "{percent} % completed" : "{percent} % utført",
    "Could not delete the task." : "Kunne ikke slette oppgaven.",
    "An error occurred" : "En feil oppstod"
},
"nplurals=2; plural=(n != 1);");
